metertools.Meter
================

.. abjad-lineage:: abjad.tools.metertools.Meter.Meter

.. autoclass:: abjad.tools.metertools.Meter.Meter

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.metertools.Meter.Meter.decrease_durations_monotonically
      ~abjad.tools.metertools.Meter.Meter.denominator
      ~abjad.tools.metertools.Meter.Meter.depthwise_offset_inventory
      ~abjad.tools.metertools.Meter.Meter.fit_meters_to_expr
      ~abjad.tools.metertools.Meter.Meter.generate_offset_kernel_to_denominator
      ~abjad.tools.metertools.Meter.Meter.graphviz_format
      ~abjad.tools.metertools.Meter.Meter.implied_time_signature
      ~abjad.tools.metertools.Meter.Meter.numerator
      ~abjad.tools.metertools.Meter.Meter.preprolated_duration
      ~abjad.tools.metertools.Meter.Meter.pretty_rtm_format
      ~abjad.tools.metertools.Meter.Meter.root_node
      ~abjad.tools.metertools.Meter.Meter.rtm_format
      ~abjad.tools.metertools.Meter.Meter.__eq__
      ~abjad.tools.metertools.Meter.Meter.__format__
      ~abjad.tools.metertools.Meter.Meter.__hash__
      ~abjad.tools.metertools.Meter.Meter.__iter__
      ~abjad.tools.metertools.Meter.Meter.__ne__
      ~abjad.tools.metertools.Meter.Meter.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.metertools.Meter.Meter.decrease_durations_monotonically
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.denominator
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.depthwise_offset_inventory
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.implied_time_signature
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.numerator
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.pretty_rtm_format
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.root_node
   :noindex:

.. autoattribute:: abjad.tools.metertools.Meter.Meter.rtm_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.metertools.Meter.Meter.generate_offset_kernel_to_denominator
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.metertools.Meter.Meter.fit_meters_to_expr
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.metertools.Meter.Meter.__eq__
   :noindex:

.. automethod:: abjad.tools.metertools.Meter.Meter.__format__
   :noindex:

.. automethod:: abjad.tools.metertools.Meter.Meter.__hash__
   :noindex:

.. automethod:: abjad.tools.metertools.Meter.Meter.__iter__
   :noindex:

.. automethod:: abjad.tools.metertools.Meter.Meter.__ne__
   :noindex:

.. automethod:: abjad.tools.metertools.Meter.Meter.__repr__
   :noindex:
